@@ -3,9 +3,9 @@ test_that("we can call the trpohic ecology information  table", {
   needs_api()
 
   df <- diet_items("Oreochromis niloticus")
-  expect_is(df, "data.frame")
+  expect_is(df, "tbl")
     
   df <- fooditems("Oreochromis niloticus")
-  expect_is(df, "data.frame")
+  expect_is(df, "tbl")
 })
 
